pub struct Expression(pub ArenaIdx<ExpressionInner>);Expand description
Expression
Tuple Fields
0: ArenaIdx<ExpressionInner>Implementations
Sourceimpl Expression
impl Expression
Sourcepub fn as_literal(&self) -> Option<&LiteralExpression>
pub fn as_literal(&self) -> Option<&LiteralExpression>
Gets a literal out of this expression, if it is one.
Sourcepub fn as_string_literal(&self) -> Option<&StringLiteral>
pub fn as_string_literal(&self) -> Option<&StringLiteral>
Gets a string literal out of this expression, if it is one.
Sourcepub fn as_integer_literal(&self) -> Option<&IntegerLiteral>
pub fn as_integer_literal(&self) -> Option<&IntegerLiteral>
Gets an integer literal out of this expression, if it is one.