pub struct ExpressionWithBlock(pub WithOuterAttributes<ExpressionWithBlockInner>);Expand description
ExpressionWithBlock
Tuple Fields
0: WithOuterAttributes<ExpressionWithBlockInner>Trait Implementations
Sourceimpl Clone for ExpressionWithBlock
impl Clone for ExpressionWithBlock
Sourcefn clone(&self) -> ExpressionWithBlock
fn clone(&self) -> ExpressionWithBlock
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExpressionWithBlock
impl Debug for ExpressionWithBlock
Sourceimpl<'de> Deserialize<'de> for ExpressionWithBlock
impl<'de> Deserialize<'de> for ExpressionWithBlock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for ExpressionWithBlock
impl Format<WhitespaceConfig, ()> for ExpressionWithBlock
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for ExpressionWithBlock
impl Formattable for ExpressionWithBlock
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<ExpressionWithBlock> for ExpressionInner
impl From<ExpressionWithBlock> for ExpressionInner
Sourcefn from(value: ExpressionWithBlock) -> Self
fn from(value: ExpressionWithBlock) -> Self
Converts to this type from the input type.
Sourceimpl Parse for ExpressionWithBlock
impl Parse for ExpressionWithBlock
Sourceimpl PartialEq for ExpressionWithBlock
impl PartialEq for ExpressionWithBlock
Sourceimpl Print for ExpressionWithBlock
impl Print for ExpressionWithBlock
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for ExpressionWithBlock
impl Serialize for ExpressionWithBlock
Sourceimpl TryFrom<ExpressionInner> for ExpressionWithBlock
impl TryFrom<ExpressionInner> for ExpressionWithBlock
Sourcetype Error = TryIntoError<ExpressionInner>
type Error = TryIntoError<ExpressionInner>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: ExpressionInner,
) -> Result<Self, TryIntoError<ExpressionInner>>
fn try_from( value: ExpressionInner, ) -> Result<Self, TryIntoError<ExpressionInner>>
Performs the conversion.
impl Eq for ExpressionWithBlock
impl StructuralPartialEq for ExpressionWithBlock