pub struct AsyncBlockExpression {
pub async_: Async,
pub move_: Option<Move>,
pub block: Box<BlockExpression>,
}Expand description
AsyncBlockExpression
Fields
async_: Asyncmove_: Option<Move>block: Box<BlockExpression>Trait Implementations
Sourceimpl Clone for AsyncBlockExpression
impl Clone for AsyncBlockExpression
Sourcefn clone(&self) -> AsyncBlockExpression
fn clone(&self) -> AsyncBlockExpression
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AsyncBlockExpression
impl Debug for AsyncBlockExpression
Sourceimpl<'de> Deserialize<'de> for AsyncBlockExpression
impl<'de> Deserialize<'de> for AsyncBlockExpression
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for AsyncBlockExpression
impl Format<WhitespaceConfig, ()> for AsyncBlockExpression
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for AsyncBlockExpression
impl Formattable for AsyncBlockExpression
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<AsyncBlockExpression> for ExpressionWithoutBlockInner
impl From<AsyncBlockExpression> for ExpressionWithoutBlockInner
Sourcefn from(value: AsyncBlockExpression) -> Self
fn from(value: AsyncBlockExpression) -> Self
Converts to this type from the input type.
Sourceimpl Parse for AsyncBlockExpression
impl Parse for AsyncBlockExpression
Sourceimpl PartialEq for AsyncBlockExpression
impl PartialEq for AsyncBlockExpression
Sourceimpl Print for AsyncBlockExpression
impl Print for AsyncBlockExpression
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for AsyncBlockExpression
impl Serialize for AsyncBlockExpression
Sourceimpl TryFrom<ExpressionWithoutBlockInner> for AsyncBlockExpression
impl TryFrom<ExpressionWithoutBlockInner> for AsyncBlockExpression
Sourcetype Error = TryIntoError<ExpressionWithoutBlockInner>
type Error = TryIntoError<ExpressionWithoutBlockInner>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: ExpressionWithoutBlockInner,
) -> Result<Self, TryIntoError<ExpressionWithoutBlockInner>>
fn try_from( value: ExpressionWithoutBlockInner, ) -> Result<Self, TryIntoError<ExpressionWithoutBlockInner>>
Performs the conversion.
impl Eq for AsyncBlockExpression
impl StructuralPartialEq for AsyncBlockExpression