pub struct ClosureExpression {
pub for_: Option<ForLifetimes>,
pub async_: Option<Async>,
pub move_: Option<Move>,
pub params: ClosureParams,
pub ret: Option<ClosureRet>,
pub expr: Expression,
}Fields
for_: Option<ForLifetimes>async_: Option<Async>move_: Option<Move>params: ClosureParamsret: Option<ClosureRet>expr: ExpressionTrait Implementations
Sourceimpl Clone for ClosureExpression
impl Clone for ClosureExpression
Sourcefn clone(&self) -> ClosureExpression
fn clone(&self) -> ClosureExpression
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClosureExpression
impl Debug for ClosureExpression
Sourceimpl<'de> Deserialize<'de> for ClosureExpression
impl<'de> Deserialize<'de> for ClosureExpression
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for ClosureExpression
impl Format<WhitespaceConfig, ()> for ClosureExpression
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for ClosureExpression
impl Formattable for ClosureExpression
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<ClosureExpression> for ExpressionWithoutBlockInner
impl From<ClosureExpression> for ExpressionWithoutBlockInner
Sourcefn from(value: ClosureExpression) -> Self
fn from(value: ClosureExpression) -> Self
Converts to this type from the input type.
Sourceimpl IntoRecursiveRoot<ExpressionInner> for ClosureExpression
impl IntoRecursiveRoot<ExpressionInner> for ClosureExpression
fn into_recursive_root(self, parser: &mut Parser) -> ExpressionInner
Sourceimpl ParsableRecursive<ExpressionInner> for ClosureExpression
impl ParsableRecursive<ExpressionInner> for ClosureExpression
Sourcetype Prefix = ClosureExpressionPrefix
type Prefix = ClosureExpressionPrefix
The prefix for this type
Sourcefn join_prefix(
prefix: Self::Prefix,
lhs: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_prefix( prefix: Self::Prefix, lhs: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_suffix(
lhs: ExpressionInner,
suffix: Self::Suffix,
parser: &mut Parser,
) -> Self
fn join_suffix( lhs: ExpressionInner, suffix: Self::Suffix, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_infix(
_: ExpressionInner,
infix: Self::Infix,
_: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_infix( _: ExpressionInner, infix: Self::Infix, _: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourceimpl PartialEq for ClosureExpression
impl PartialEq for ClosureExpression
Sourceimpl Print for ClosureExpression
impl Print for ClosureExpression
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for ClosureExpression
impl Serialize for ClosureExpression
Sourceimpl TryFrom<ExpressionWithoutBlockInner> for ClosureExpression
impl TryFrom<ExpressionWithoutBlockInner> for ClosureExpression
Sourcetype Error = TryIntoError<ExpressionWithoutBlockInner>
type Error = TryIntoError<ExpressionWithoutBlockInner>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: ExpressionWithoutBlockInner,
) -> Result<Self, TryIntoError<ExpressionWithoutBlockInner>>
fn try_from( value: ExpressionWithoutBlockInner, ) -> Result<Self, TryIntoError<ExpressionWithoutBlockInner>>
Performs the conversion.
Sourceimpl TryFromRecursiveRoot<ExpressionInner> for ClosureExpression
impl TryFromRecursiveRoot<ExpressionInner> for ClosureExpression
fn try_from_recursive_root( root: ExpressionInner, parser: &mut Parser, ) -> Option<Self>
impl Eq for ClosureExpression
impl StructuralPartialEq for ClosureExpression