pub struct MacroInvocation {
pub path: SimplePath,
pub not: Not,
pub tree: DelimTokenTree,
}Expand description
MacroInvocation
Fields
path: SimplePathnot: Nottree: DelimTokenTreeTrait Implementations
Sourceimpl Clone for MacroInvocation
impl Clone for MacroInvocation
Sourcefn clone(&self) -> MacroInvocation
fn clone(&self) -> MacroInvocation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MacroInvocation
impl Debug for MacroInvocation
Sourceimpl<'de> Deserialize<'de> for MacroInvocation
impl<'de> Deserialize<'de> for MacroInvocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for MacroInvocation
impl Format<WhitespaceConfig, ()> for MacroInvocation
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for MacroInvocation
impl Formattable for MacroInvocation
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<MacroInvocation> for ExpressionWithoutBlockInner
impl From<MacroInvocation> for ExpressionWithoutBlockInner
Sourcefn from(value: MacroInvocation) -> Self
fn from(value: MacroInvocation) -> Self
Converts to this type from the input type.
Sourceimpl From<MacroInvocation> for TypeNoBounds
impl From<MacroInvocation> for TypeNoBounds
Sourcefn from(value: MacroInvocation) -> Self
fn from(value: MacroInvocation) -> Self
Converts to this type from the input type.
Sourceimpl Parse for MacroInvocation
impl Parse for MacroInvocation
Sourceimpl PartialEq for MacroInvocation
impl PartialEq for MacroInvocation
Sourceimpl Print for MacroInvocation
impl Print for MacroInvocation
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for MacroInvocation
impl Serialize for MacroInvocation
Sourceimpl TryFrom<ExpressionWithoutBlockInner> for MacroInvocation
impl TryFrom<ExpressionWithoutBlockInner> for MacroInvocation
Sourcetype Error = TryIntoError<ExpressionWithoutBlockInner>
type Error = TryIntoError<ExpressionWithoutBlockInner>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: ExpressionWithoutBlockInner,
) -> Result<Self, TryIntoError<ExpressionWithoutBlockInner>>
fn try_from( value: ExpressionWithoutBlockInner, ) -> Result<Self, TryIntoError<ExpressionWithoutBlockInner>>
Performs the conversion.
impl Eq for MacroInvocation
impl StructuralPartialEq for MacroInvocation