pub struct ArithmeticOrLogicalExpression {
pub lhs: Expression,
pub op: ArithmeticOrLogicalExpressionOp,
pub rhs: Expression,
}Expand description
ArithmeticOrLogicalExpression
Fields
lhs: Expressionop: ArithmeticOrLogicalExpressionOprhs: ExpressionTrait Implementations
Sourceimpl Clone for ArithmeticOrLogicalExpression
impl Clone for ArithmeticOrLogicalExpression
Sourcefn clone(&self) -> ArithmeticOrLogicalExpression
fn clone(&self) -> ArithmeticOrLogicalExpression
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ArithmeticOrLogicalExpression
impl<'de> Deserialize<'de> for ArithmeticOrLogicalExpression
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for ArithmeticOrLogicalExpression
impl Format<WhitespaceConfig, ()> for ArithmeticOrLogicalExpression
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for ArithmeticOrLogicalExpression
impl Formattable for ArithmeticOrLogicalExpression
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<ArithmeticOrLogicalExpression> for OperatorExpression
impl From<ArithmeticOrLogicalExpression> for OperatorExpression
Sourcefn from(value: ArithmeticOrLogicalExpression) -> Self
fn from(value: ArithmeticOrLogicalExpression) -> Self
Converts to this type from the input type.
Sourceimpl IntoRecursiveRoot<ExpressionInner> for ArithmeticOrLogicalExpression
impl IntoRecursiveRoot<ExpressionInner> for ArithmeticOrLogicalExpression
fn into_recursive_root(self, parser: &mut Parser) -> ExpressionInner
Sourceimpl ParsableRecursive<ExpressionInner> for ArithmeticOrLogicalExpression
impl ParsableRecursive<ExpressionInner> for ArithmeticOrLogicalExpression
Sourcetype Infix = ArithmeticOrLogicalExpressionInfix
type Infix = ArithmeticOrLogicalExpressionInfix
The infix of this type
Sourcefn join_prefix(
prefix: Self::Prefix,
_: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_prefix( prefix: Self::Prefix, _: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_suffix(
lhs: ExpressionInner,
suffix: Self::Suffix,
parser: &mut Parser,
) -> Self
fn join_suffix( lhs: ExpressionInner, suffix: Self::Suffix, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_infix(
lhs: ExpressionInner,
infix: Self::Infix,
rhs: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_infix( lhs: ExpressionInner, infix: Self::Infix, rhs: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourceimpl PartialEq for ArithmeticOrLogicalExpression
impl PartialEq for ArithmeticOrLogicalExpression
Sourcefn eq(&self, other: &ArithmeticOrLogicalExpression) -> bool
fn eq(&self, other: &ArithmeticOrLogicalExpression) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Print for ArithmeticOrLogicalExpression
impl Print for ArithmeticOrLogicalExpression
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl TryFrom<OperatorExpression> for ArithmeticOrLogicalExpression
impl TryFrom<OperatorExpression> for ArithmeticOrLogicalExpression
Sourcetype Error = TryIntoError<OperatorExpression>
type Error = TryIntoError<OperatorExpression>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: OperatorExpression,
) -> Result<Self, TryIntoError<OperatorExpression>>
fn try_from( value: OperatorExpression, ) -> Result<Self, TryIntoError<OperatorExpression>>
Performs the conversion.
Sourceimpl TryFromRecursiveRoot<ExpressionInner> for ArithmeticOrLogicalExpression
impl TryFromRecursiveRoot<ExpressionInner> for ArithmeticOrLogicalExpression
fn try_from_recursive_root( root: ExpressionInner, parser: &mut Parser, ) -> Option<Self>
impl Eq for ArithmeticOrLogicalExpression
impl StructuralPartialEq for ArithmeticOrLogicalExpression