pub struct ComparisonExpression {
pub lhs: Expression,
pub op: ComparisonExpressionOp,
pub rhs: Expression,
}Expand description
ComparisonExpression
Fields
lhs: Expressionop: ComparisonExpressionOprhs: ExpressionTrait Implementations
Sourceimpl Clone for ComparisonExpression
impl Clone for ComparisonExpression
Sourcefn clone(&self) -> ComparisonExpression
fn clone(&self) -> ComparisonExpression
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComparisonExpression
impl Debug for ComparisonExpression
Sourceimpl<'de> Deserialize<'de> for ComparisonExpression
impl<'de> Deserialize<'de> for ComparisonExpression
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for ComparisonExpression
impl Format<WhitespaceConfig, ()> for ComparisonExpression
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for ComparisonExpression
impl Formattable for ComparisonExpression
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<ComparisonExpression> for OperatorExpression
impl From<ComparisonExpression> for OperatorExpression
Sourcefn from(value: ComparisonExpression) -> Self
fn from(value: ComparisonExpression) -> Self
Converts to this type from the input type.
Sourceimpl IntoRecursiveRoot<ExpressionInner> for ComparisonExpression
impl IntoRecursiveRoot<ExpressionInner> for ComparisonExpression
fn into_recursive_root(self, parser: &mut Parser) -> ExpressionInner
Sourceimpl ParsableRecursive<ExpressionInner> for ComparisonExpression
impl ParsableRecursive<ExpressionInner> for ComparisonExpression
Sourcetype Infix = ComparisonExpressionInfix
type Infix = ComparisonExpressionInfix
The infix of this type
Sourcefn join_prefix(
prefix: Self::Prefix,
_: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_prefix( prefix: Self::Prefix, _: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_suffix(
lhs: ExpressionInner,
suffix: Self::Suffix,
parser: &mut Parser,
) -> Self
fn join_suffix( lhs: ExpressionInner, suffix: Self::Suffix, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_infix(
lhs: ExpressionInner,
infix: Self::Infix,
rhs: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_infix( lhs: ExpressionInner, infix: Self::Infix, rhs: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourceimpl PartialEq for ComparisonExpression
impl PartialEq for ComparisonExpression
Sourceimpl Print for ComparisonExpression
impl Print for ComparisonExpression
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for ComparisonExpression
impl Serialize for ComparisonExpression
Sourceimpl TryFrom<OperatorExpression> for ComparisonExpression
impl TryFrom<OperatorExpression> for ComparisonExpression
Sourcetype Error = TryIntoError<OperatorExpression>
type Error = TryIntoError<OperatorExpression>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: OperatorExpression,
) -> Result<Self, TryIntoError<OperatorExpression>>
fn try_from( value: OperatorExpression, ) -> Result<Self, TryIntoError<OperatorExpression>>
Performs the conversion.
Sourceimpl TryFromRecursiveRoot<ExpressionInner> for ComparisonExpression
impl TryFromRecursiveRoot<ExpressionInner> for ComparisonExpression
fn try_from_recursive_root( root: ExpressionInner, parser: &mut Parser, ) -> Option<Self>
impl Eq for ComparisonExpression
impl StructuralPartialEq for ComparisonExpression