pub struct CompoundAssignmentExpression {
pub lhs: Expression,
pub op: CompoundAssignmentExpressionOp,
pub rhs: Expression,
}Expand description
CompoundAssignmentExpression
Fields
lhs: Expressionop: CompoundAssignmentExpressionOprhs: ExpressionTrait Implementations
Sourceimpl Clone for CompoundAssignmentExpression
impl Clone for CompoundAssignmentExpression
Sourcefn clone(&self) -> CompoundAssignmentExpression
fn clone(&self) -> CompoundAssignmentExpression
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompoundAssignmentExpression
impl Debug for CompoundAssignmentExpression
Sourceimpl<'de> Deserialize<'de> for CompoundAssignmentExpression
impl<'de> Deserialize<'de> for CompoundAssignmentExpression
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for CompoundAssignmentExpression
impl Format<WhitespaceConfig, ()> for CompoundAssignmentExpression
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for CompoundAssignmentExpression
impl Formattable for CompoundAssignmentExpression
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<CompoundAssignmentExpression> for OperatorExpression
impl From<CompoundAssignmentExpression> for OperatorExpression
Sourcefn from(value: CompoundAssignmentExpression) -> Self
fn from(value: CompoundAssignmentExpression) -> Self
Converts to this type from the input type.
Sourceimpl IntoRecursiveRoot<ExpressionInner> for CompoundAssignmentExpression
impl IntoRecursiveRoot<ExpressionInner> for CompoundAssignmentExpression
fn into_recursive_root(self, parser: &mut Parser) -> ExpressionInner
Sourceimpl ParsableRecursive<ExpressionInner> for CompoundAssignmentExpression
impl ParsableRecursive<ExpressionInner> for CompoundAssignmentExpression
Sourcetype Infix = CompoundAssignmentExpressionInfix
type Infix = CompoundAssignmentExpressionInfix
The infix of this type
Sourcefn join_prefix(
prefix: Self::Prefix,
_: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_prefix( prefix: Self::Prefix, _: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_suffix(
lhs: ExpressionInner,
suffix: Self::Suffix,
parser: &mut Parser,
) -> Self
fn join_suffix( lhs: ExpressionInner, suffix: Self::Suffix, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_infix(
lhs: ExpressionInner,
infix: Self::Infix,
rhs: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_infix( lhs: ExpressionInner, infix: Self::Infix, rhs: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourceimpl PartialEq for CompoundAssignmentExpression
impl PartialEq for CompoundAssignmentExpression
Sourcefn eq(&self, other: &CompoundAssignmentExpression) -> bool
fn eq(&self, other: &CompoundAssignmentExpression) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Print for CompoundAssignmentExpression
impl Print for CompoundAssignmentExpression
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl TryFrom<OperatorExpression> for CompoundAssignmentExpression
impl TryFrom<OperatorExpression> for CompoundAssignmentExpression
Sourcetype Error = TryIntoError<OperatorExpression>
type Error = TryIntoError<OperatorExpression>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: OperatorExpression,
) -> Result<Self, TryIntoError<OperatorExpression>>
fn try_from( value: OperatorExpression, ) -> Result<Self, TryIntoError<OperatorExpression>>
Performs the conversion.
Sourceimpl TryFromRecursiveRoot<ExpressionInner> for CompoundAssignmentExpression
impl TryFromRecursiveRoot<ExpressionInner> for CompoundAssignmentExpression
fn try_from_recursive_root( root: ExpressionInner, parser: &mut Parser, ) -> Option<Self>
impl Eq for CompoundAssignmentExpression
impl StructuralPartialEq for CompoundAssignmentExpression