pub struct DereferenceExpression {
pub star: Star,
pub expr: Expression,
}Expand description
DereferenceExpression
Fields
star: Starexpr: ExpressionTrait Implementations
Sourceimpl Clone for DereferenceExpression
impl Clone for DereferenceExpression
Sourcefn clone(&self) -> DereferenceExpression
fn clone(&self) -> DereferenceExpression
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DereferenceExpression
impl Debug for DereferenceExpression
Sourceimpl<'de> Deserialize<'de> for DereferenceExpression
impl<'de> Deserialize<'de> for DereferenceExpression
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for DereferenceExpression
impl Format<WhitespaceConfig, ()> for DereferenceExpression
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for DereferenceExpression
impl Formattable for DereferenceExpression
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<DereferenceExpression> for OperatorExpression
impl From<DereferenceExpression> for OperatorExpression
Sourcefn from(value: DereferenceExpression) -> Self
fn from(value: DereferenceExpression) -> Self
Converts to this type from the input type.
Sourceimpl IntoRecursiveRoot<ExpressionInner> for DereferenceExpression
impl IntoRecursiveRoot<ExpressionInner> for DereferenceExpression
fn into_recursive_root(self, parser: &mut Parser) -> ExpressionInner
Sourceimpl ParsableRecursive<ExpressionInner> for DereferenceExpression
impl ParsableRecursive<ExpressionInner> for DereferenceExpression
Sourcetype Prefix = DereferenceExpressionPrefix
type Prefix = DereferenceExpressionPrefix
The prefix for this type
Sourcefn join_prefix(
prefix: Self::Prefix,
lhs: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_prefix( prefix: Self::Prefix, lhs: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_suffix(
lhs: ExpressionInner,
suffix: Self::Suffix,
parser: &mut Parser,
) -> Self
fn join_suffix( lhs: ExpressionInner, suffix: Self::Suffix, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_infix(
_: ExpressionInner,
infix: Self::Infix,
_: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_infix( _: ExpressionInner, infix: Self::Infix, _: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourceimpl PartialEq for DereferenceExpression
impl PartialEq for DereferenceExpression
Sourceimpl Print for DereferenceExpression
impl Print for DereferenceExpression
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for DereferenceExpression
impl Serialize for DereferenceExpression
Sourceimpl TryFrom<OperatorExpression> for DereferenceExpression
impl TryFrom<OperatorExpression> for DereferenceExpression
Sourcetype Error = TryIntoError<OperatorExpression>
type Error = TryIntoError<OperatorExpression>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: OperatorExpression,
) -> Result<Self, TryIntoError<OperatorExpression>>
fn try_from( value: OperatorExpression, ) -> Result<Self, TryIntoError<OperatorExpression>>
Performs the conversion.
Sourceimpl TryFromRecursiveRoot<ExpressionInner> for DereferenceExpression
impl TryFromRecursiveRoot<ExpressionInner> for DereferenceExpression
fn try_from_recursive_root( root: ExpressionInner, parser: &mut Parser, ) -> Option<Self>
impl Eq for DereferenceExpression
impl StructuralPartialEq for DereferenceExpression