pub struct NegationExpression {
pub token: NegationExpressionToken,
pub expr: Expression,
}Expand description
NegationExpression
Fields
token: NegationExpressionTokenexpr: ExpressionTrait Implementations
Sourceimpl Clone for NegationExpression
impl Clone for NegationExpression
Sourcefn clone(&self) -> NegationExpression
fn clone(&self) -> NegationExpression
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NegationExpression
impl Debug for NegationExpression
Sourceimpl<'de> Deserialize<'de> for NegationExpression
impl<'de> Deserialize<'de> for NegationExpression
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for NegationExpression
impl Format<WhitespaceConfig, ()> for NegationExpression
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for NegationExpression
impl Formattable for NegationExpression
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<NegationExpression> for OperatorExpression
impl From<NegationExpression> for OperatorExpression
Sourcefn from(value: NegationExpression) -> Self
fn from(value: NegationExpression) -> Self
Converts to this type from the input type.
Sourceimpl IntoRecursiveRoot<ExpressionInner> for NegationExpression
impl IntoRecursiveRoot<ExpressionInner> for NegationExpression
fn into_recursive_root(self, parser: &mut Parser) -> ExpressionInner
Sourceimpl ParsableRecursive<ExpressionInner> for NegationExpression
impl ParsableRecursive<ExpressionInner> for NegationExpression
Sourcetype Prefix = NegationExpressionPrefix
type Prefix = NegationExpressionPrefix
The prefix for this type
Sourcefn join_prefix(
prefix: Self::Prefix,
lhs: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_prefix( prefix: Self::Prefix, lhs: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_suffix(
lhs: ExpressionInner,
suffix: Self::Suffix,
parser: &mut Parser,
) -> Self
fn join_suffix( lhs: ExpressionInner, suffix: Self::Suffix, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_infix(
_: ExpressionInner,
infix: Self::Infix,
_: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_infix( _: ExpressionInner, infix: Self::Infix, _: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourceimpl PartialEq for NegationExpression
impl PartialEq for NegationExpression
Sourceimpl Print for NegationExpression
impl Print for NegationExpression
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for NegationExpression
impl Serialize for NegationExpression
Sourceimpl TryFrom<OperatorExpression> for NegationExpression
impl TryFrom<OperatorExpression> for NegationExpression
Sourcetype Error = TryIntoError<OperatorExpression>
type Error = TryIntoError<OperatorExpression>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: OperatorExpression,
) -> Result<Self, TryIntoError<OperatorExpression>>
fn try_from( value: OperatorExpression, ) -> Result<Self, TryIntoError<OperatorExpression>>
Performs the conversion.
Sourceimpl TryFromRecursiveRoot<ExpressionInner> for NegationExpression
impl TryFromRecursiveRoot<ExpressionInner> for NegationExpression
fn try_from_recursive_root( root: ExpressionInner, parser: &mut Parser, ) -> Option<Self>
impl Eq for NegationExpression
impl StructuralPartialEq for NegationExpression