pub struct RangeExpr {
pub lhs: Expression,
pub dot_dot: DotDot,
pub rhs: Expression,
}Expand description
RangeExpr
Fields
lhs: Expressiondot_dot: DotDotrhs: ExpressionTrait Implementations
Sourceimpl<'de> Deserialize<'de> for RangeExpr
impl<'de> Deserialize<'de> for RangeExpr
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for RangeExpr
impl Format<WhitespaceConfig, ()> for RangeExpr
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for RangeExpr
impl Formattable for RangeExpr
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<RangeExpr> for RangeExpression
impl From<RangeExpr> for RangeExpression
Sourceimpl IntoRecursiveRoot<ExpressionInner> for RangeExpr
impl IntoRecursiveRoot<ExpressionInner> for RangeExpr
fn into_recursive_root(self, parser: &mut Parser) -> ExpressionInner
Sourceimpl ParsableRecursive<ExpressionInner> for RangeExpr
impl ParsableRecursive<ExpressionInner> for RangeExpr
Sourcetype Infix = RangeExprInfix
type Infix = RangeExprInfix
The infix of this type
Sourcefn join_prefix(
prefix: Self::Prefix,
_: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_prefix( prefix: Self::Prefix, _: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_suffix(
lhs: ExpressionInner,
suffix: Self::Suffix,
parser: &mut Parser,
) -> Self
fn join_suffix( lhs: ExpressionInner, suffix: Self::Suffix, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_infix(
lhs: ExpressionInner,
infix: Self::Infix,
rhs: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_infix( lhs: ExpressionInner, infix: Self::Infix, rhs: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourceimpl Print for RangeExpr
impl Print for RangeExpr
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl TryFrom<RangeExpression> for RangeExpr
impl TryFrom<RangeExpression> for RangeExpr
Sourcetype Error = TryIntoError<RangeExpression>
type Error = TryIntoError<RangeExpression>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: RangeExpression,
) -> Result<Self, TryIntoError<RangeExpression>>
fn try_from( value: RangeExpression, ) -> Result<Self, TryIntoError<RangeExpression>>
Performs the conversion.
Sourceimpl TryFromRecursiveRoot<ExpressionInner> for RangeExpr
impl TryFromRecursiveRoot<ExpressionInner> for RangeExpr
fn try_from_recursive_root( root: ExpressionInner, parser: &mut Parser, ) -> Option<Self>
impl Eq for RangeExpr
impl StructuralPartialEq for RangeExpr