pub struct RangeFromExpr {
pub lhs: Expression,
pub dot_dot: DotDot,
}Expand description
RangeFromExpr
Fields
lhs: Expressiondot_dot: DotDotTrait Implementations
Sourceimpl Clone for RangeFromExpr
impl Clone for RangeFromExpr
Sourcefn clone(&self) -> RangeFromExpr
fn clone(&self) -> RangeFromExpr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RangeFromExpr
impl Debug for RangeFromExpr
Sourceimpl<'de> Deserialize<'de> for RangeFromExpr
impl<'de> Deserialize<'de> for RangeFromExpr
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for RangeFromExpr
impl Format<WhitespaceConfig, ()> for RangeFromExpr
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for RangeFromExpr
impl Formattable for RangeFromExpr
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<RangeFromExpr> for RangeExpression
impl From<RangeFromExpr> for RangeExpression
Sourcefn from(value: RangeFromExpr) -> Self
fn from(value: RangeFromExpr) -> Self
Converts to this type from the input type.
Sourceimpl IntoRecursiveRoot<ExpressionInner> for RangeFromExpr
impl IntoRecursiveRoot<ExpressionInner> for RangeFromExpr
fn into_recursive_root(self, parser: &mut Parser) -> ExpressionInner
Sourceimpl ParsableRecursive<ExpressionInner> for RangeFromExpr
impl ParsableRecursive<ExpressionInner> for RangeFromExpr
Sourcetype Suffix = RangeFromExprSuffix
type Suffix = RangeFromExprSuffix
The suffix for this type
Sourcefn join_prefix(
prefix: Self::Prefix,
_: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_prefix( prefix: Self::Prefix, _: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_suffix(
lhs: ExpressionInner,
suffix: Self::Suffix,
parser: &mut Parser,
) -> Self
fn join_suffix( lhs: ExpressionInner, suffix: Self::Suffix, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_infix(
_: ExpressionInner,
infix: Self::Infix,
_: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_infix( _: ExpressionInner, infix: Self::Infix, _: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourceimpl PartialEq for RangeFromExpr
impl PartialEq for RangeFromExpr
Sourceimpl Print for RangeFromExpr
impl Print for RangeFromExpr
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for RangeFromExpr
impl Serialize for RangeFromExpr
Sourceimpl TryFrom<RangeExpression> for RangeFromExpr
impl TryFrom<RangeExpression> for RangeFromExpr
Sourcetype Error = TryIntoError<RangeExpression>
type Error = TryIntoError<RangeExpression>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: RangeExpression,
) -> Result<Self, TryIntoError<RangeExpression>>
fn try_from( value: RangeExpression, ) -> Result<Self, TryIntoError<RangeExpression>>
Performs the conversion.
Sourceimpl TryFromRecursiveRoot<ExpressionInner> for RangeFromExpr
impl TryFromRecursiveRoot<ExpressionInner> for RangeFromExpr
fn try_from_recursive_root( root: ExpressionInner, parser: &mut Parser, ) -> Option<Self>
impl Eq for RangeFromExpr
impl StructuralPartialEq for RangeFromExpr