pub struct ExpressionWithoutBlock(pub WithOuterAttributes<ExpressionWithoutBlockInner>);Expand description
ExpressionWithoutBlock
Tuple Fields
0: WithOuterAttributes<ExpressionWithoutBlockInner>Trait Implementations
Sourceimpl Clone for ExpressionWithoutBlock
impl Clone for ExpressionWithoutBlock
Sourcefn clone(&self) -> ExpressionWithoutBlock
fn clone(&self) -> ExpressionWithoutBlock
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExpressionWithoutBlock
impl Debug for ExpressionWithoutBlock
Sourceimpl<'de> Deserialize<'de> for ExpressionWithoutBlock
impl<'de> Deserialize<'de> for ExpressionWithoutBlock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for ExpressionWithoutBlock
impl Format<WhitespaceConfig, ()> for ExpressionWithoutBlock
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for ExpressionWithoutBlock
impl Formattable for ExpressionWithoutBlock
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<ExpressionWithoutBlock> for ExpressionInner
impl From<ExpressionWithoutBlock> for ExpressionInner
Sourcefn from(value: ExpressionWithoutBlock) -> Self
fn from(value: ExpressionWithoutBlock) -> Self
Converts to this type from the input type.
Sourceimpl From<ExpressionWithoutBlockInner> for ExpressionWithoutBlock
impl From<ExpressionWithoutBlockInner> for ExpressionWithoutBlock
Sourcefn from(expr: ExpressionWithoutBlockInner) -> Self
fn from(expr: ExpressionWithoutBlockInner) -> Self
Converts to this type from the input type.
Sourceimpl From<WithOuterAttributes<ExpressionWithoutBlockInner>> for ExpressionWithoutBlock
impl From<WithOuterAttributes<ExpressionWithoutBlockInner>> for ExpressionWithoutBlock
Sourcefn from(value: WithOuterAttributes<ExpressionWithoutBlockInner>) -> Self
fn from(value: WithOuterAttributes<ExpressionWithoutBlockInner>) -> Self
Converts to this type from the input type.
Sourceimpl IntoRecursiveRoot<ExpressionInner> for ExpressionWithoutBlock
impl IntoRecursiveRoot<ExpressionInner> for ExpressionWithoutBlock
fn into_recursive_root(self, parser: &mut Parser) -> ExpressionInner
Sourceimpl ParsableRecursive<ExpressionInner> for ExpressionWithoutBlock
impl ParsableRecursive<ExpressionInner> for ExpressionWithoutBlock
Sourcetype Prefix = <WithOuterAttributes<ExpressionWithoutBlockInner> as ParsableRecursive<ExpressionInner>>::Prefix
type Prefix = <WithOuterAttributes<ExpressionWithoutBlockInner> as ParsableRecursive<ExpressionInner>>::Prefix
The prefix for this type
Sourcetype Base = <WithOuterAttributes<ExpressionWithoutBlockInner> as ParsableRecursive<ExpressionInner>>::Base
type Base = <WithOuterAttributes<ExpressionWithoutBlockInner> as ParsableRecursive<ExpressionInner>>::Base
Base type
Sourcetype Suffix = <WithOuterAttributes<ExpressionWithoutBlockInner> as ParsableRecursive<ExpressionInner>>::Suffix
type Suffix = <WithOuterAttributes<ExpressionWithoutBlockInner> as ParsableRecursive<ExpressionInner>>::Suffix
The suffix for this type
Sourcetype Infix = <WithOuterAttributes<ExpressionWithoutBlockInner> as ParsableRecursive<ExpressionInner>>::Infix
type Infix = <WithOuterAttributes<ExpressionWithoutBlockInner> as ParsableRecursive<ExpressionInner>>::Infix
The infix of this type
Sourcefn join_prefix(
prefix: Self::Prefix,
root: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_prefix( prefix: Self::Prefix, root: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_suffix(
root: ExpressionInner,
suffix: Self::Suffix,
parser: &mut Parser,
) -> Self
fn join_suffix( root: ExpressionInner, suffix: Self::Suffix, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourcefn join_infix(
lhs: ExpressionInner,
infix: Self::Infix,
rhs: ExpressionInner,
parser: &mut Parser,
) -> Self
fn join_infix( lhs: ExpressionInner, infix: Self::Infix, rhs: ExpressionInner, parser: &mut Parser, ) -> Self
Creates this type from it’s parts
Sourceimpl Parse for ExpressionWithoutBlock
impl Parse for ExpressionWithoutBlock
Sourceimpl PartialEq for ExpressionWithoutBlock
impl PartialEq for ExpressionWithoutBlock
Sourceimpl Print for ExpressionWithoutBlock
impl Print for ExpressionWithoutBlock
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for ExpressionWithoutBlock
impl Serialize for ExpressionWithoutBlock
Sourceimpl TryFrom<ExpressionInner> for ExpressionWithoutBlock
impl TryFrom<ExpressionInner> for ExpressionWithoutBlock
Sourcetype Error = TryIntoError<ExpressionInner>
type Error = TryIntoError<ExpressionInner>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: ExpressionInner,
) -> Result<Self, TryIntoError<ExpressionInner>>
fn try_from( value: ExpressionInner, ) -> Result<Self, TryIntoError<ExpressionInner>>
Performs the conversion.
Sourceimpl TryFromRecursiveRoot<ExpressionInner> for ExpressionWithoutBlock
impl TryFromRecursiveRoot<ExpressionInner> for ExpressionWithoutBlock
fn try_from_recursive_root( root: ExpressionInner, parser: &mut Parser, ) -> Option<Self>
impl Eq for ExpressionWithoutBlock
impl StructuralPartialEq for ExpressionWithoutBlock