pub struct StructExprFieldInnerWithExpr {
pub start: StructExprFieldInnerWithExprStart,
pub colon: Colon,
pub expr: Expression,
}Fields
start: StructExprFieldInnerWithExprStartcolon: Colonexpr: ExpressionTrait Implementations
Sourceimpl Clone for StructExprFieldInnerWithExpr
impl Clone for StructExprFieldInnerWithExpr
Sourcefn clone(&self) -> StructExprFieldInnerWithExpr
fn clone(&self) -> StructExprFieldInnerWithExpr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructExprFieldInnerWithExpr
impl Debug for StructExprFieldInnerWithExpr
Sourceimpl<'de> Deserialize<'de> for StructExprFieldInnerWithExpr
impl<'de> Deserialize<'de> for StructExprFieldInnerWithExpr
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for StructExprFieldInnerWithExpr
impl Format<WhitespaceConfig, ()> for StructExprFieldInnerWithExpr
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for StructExprFieldInnerWithExpr
impl Formattable for StructExprFieldInnerWithExpr
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl Parse for StructExprFieldInnerWithExpr
impl Parse for StructExprFieldInnerWithExpr
Sourceimpl PartialEq for StructExprFieldInnerWithExpr
impl PartialEq for StructExprFieldInnerWithExpr
Sourcefn eq(&self, other: &StructExprFieldInnerWithExpr) -> bool
fn eq(&self, other: &StructExprFieldInnerWithExpr) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Print for StructExprFieldInnerWithExpr
impl Print for StructExprFieldInnerWithExpr
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
impl Eq for StructExprFieldInnerWithExpr
impl StructuralPartialEq for StructExprFieldInnerWithExpr