pub struct LiteralPattern {
pub minus: Option<Minus>,
pub literal: LiteralExpression,
}Expand description
LiteralPattern
Fields
minus: Option<Minus>literal: LiteralExpressionTrait Implementations
Sourceimpl Clone for LiteralPattern
impl Clone for LiteralPattern
Sourcefn clone(&self) -> LiteralPattern
fn clone(&self) -> LiteralPattern
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LiteralPattern
impl Debug for LiteralPattern
Sourceimpl<'de> Deserialize<'de> for LiteralPattern
impl<'de> Deserialize<'de> for LiteralPattern
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for LiteralPattern
impl Format<WhitespaceConfig, ()> for LiteralPattern
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for LiteralPattern
impl Formattable for LiteralPattern
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl Parse for LiteralPattern
impl Parse for LiteralPattern
Sourceimpl ParsePeeked<ByteLiteral> for LiteralPattern
impl ParsePeeked<ByteLiteral> for LiteralPattern
fn parse_from_with_peeked( _parser: &mut Parser, parsed: ByteLiteral, ) -> Result<Self, Self::Error>
Sourceimpl ParsePeeked<ByteStringLiteral> for LiteralPattern
impl ParsePeeked<ByteStringLiteral> for LiteralPattern
fn parse_from_with_peeked( _parser: &mut Parser, parsed: ByteStringLiteral, ) -> Result<Self, Self::Error>
Sourceimpl PartialEq for LiteralPattern
impl PartialEq for LiteralPattern
Sourceimpl Print for LiteralPattern
impl Print for LiteralPattern
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for LiteralPattern
impl Serialize for LiteralPattern
impl Eq for LiteralPattern
impl StructuralPartialEq for LiteralPattern