pub struct StructPatternElementsFieldsEtCetera {
pub comma: Comma,
pub et_cetera: Option<StructPatternEtCetera>,
}Fields
comma: Commaet_cetera: Option<StructPatternEtCetera>Trait Implementations
Sourceimpl Clone for StructPatternElementsFieldsEtCetera
impl Clone for StructPatternElementsFieldsEtCetera
Sourcefn clone(&self) -> StructPatternElementsFieldsEtCetera
fn clone(&self) -> StructPatternElementsFieldsEtCetera
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for StructPatternElementsFieldsEtCetera
impl<'de> Deserialize<'de> for StructPatternElementsFieldsEtCetera
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, FmtSingleOrIndent> for StructPatternElementsFieldsEtCetera
impl Format<WhitespaceConfig, FmtSingleOrIndent> for StructPatternElementsFieldsEtCetera
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: FmtSingleOrIndent,
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: FmtSingleOrIndent, ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for StructPatternElementsFieldsEtCetera
impl Formattable for StructPatternElementsFieldsEtCetera
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl PartialEq for StructPatternElementsFieldsEtCetera
impl PartialEq for StructPatternElementsFieldsEtCetera
Sourcefn eq(&self, other: &StructPatternElementsFieldsEtCetera) -> bool
fn eq(&self, other: &StructPatternElementsFieldsEtCetera) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Print for StructPatternElementsFieldsEtCetera
impl Print for StructPatternElementsFieldsEtCetera
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
impl Eq for StructPatternElementsFieldsEtCetera
impl StructuralPartialEq for StructPatternElementsFieldsEtCetera