pub struct QualifiedPathInType {
pub qualified: QualifiedPathType,
pub segments: AtLeast1<QualifiedPathInTypeSegment>,
}Expand description
QualifiedPathInType
Fields
qualified: QualifiedPathTypesegments: AtLeast1<QualifiedPathInTypeSegment>Trait Implementations
Sourceimpl Clone for QualifiedPathInType
impl Clone for QualifiedPathInType
Sourcefn clone(&self) -> QualifiedPathInType
fn clone(&self) -> QualifiedPathInType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QualifiedPathInType
impl Debug for QualifiedPathInType
Sourceimpl<'de> Deserialize<'de> for QualifiedPathInType
impl<'de> Deserialize<'de> for QualifiedPathInType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Format<WhitespaceConfig, ()> for QualifiedPathInType
impl Format<WhitespaceConfig, ()> for QualifiedPathInType
Sourcefn format(
&mut self,
ctx: &mut Context<'_>,
prefix_ws: WhitespaceConfig,
args: (),
) -> FormatOutput
fn format( &mut self, ctx: &mut Context<'_>, prefix_ws: WhitespaceConfig, args: (), ) -> FormatOutput
Formats this type.
Sourceimpl Formattable for QualifiedPathInType
impl Formattable for QualifiedPathInType
Sourcefn with_prefix_ws<WITH_PREFIX_WS_O>(
&mut self,
ctx: &mut Context<'_>,
f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O,
) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
fn with_prefix_ws<WITH_PREFIX_WS_O>( &mut self, ctx: &mut Context<'_>, f: &mut impl FnMut(&mut Whitespace, &mut Context<'_>) -> WITH_PREFIX_WS_O, ) -> Result<WITH_PREFIX_WS_O, ControlFlow<()>>
Accesses the prefix whitespace of this type. Read more
Sourcefn with_strings<WITH_STRINGS_O>(
&mut self,
ctx: &mut Context<'_>,
exclude_prefix_ws: bool,
f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>,
) -> ControlFlow<WITH_STRINGS_O, bool>
fn with_strings<WITH_STRINGS_O>( &mut self, ctx: &mut Context<'_>, exclude_prefix_ws: bool, f: &mut impl FnMut(&mut AstStr, &mut Context<'_>) -> ControlFlow<WITH_STRINGS_O>, ) -> ControlFlow<WITH_STRINGS_O, bool>
Iterates over all strings in this type. Read more
Sourcefn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
fn format_output(&mut self, ctx: &mut Context<'_>) -> FormatOutput
Returns the formatting output for this type, without formatting it.
Sourcefn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
fn prefix_ws_is_pure(&mut self, ctx: &mut Context<'_>) -> Option<bool>
Returns if the prefix whitespace is pure.
Sourcefn prefix_ws_join_prefix(
&mut self,
ctx: &mut Context<'_>,
ws: Whitespace,
) -> Result<(), Whitespace>
fn prefix_ws_join_prefix( &mut self, ctx: &mut Context<'_>, ws: Whitespace, ) -> Result<(), Whitespace>
Joins a string as a prefix onto the prefix whitespace of this type.
Sourceimpl From<QualifiedPathInType> for TypeNoBounds
impl From<QualifiedPathInType> for TypeNoBounds
Sourcefn from(value: QualifiedPathInType) -> Self
fn from(value: QualifiedPathInType) -> Self
Converts to this type from the input type.
Sourceimpl Parse for QualifiedPathInType
impl Parse for QualifiedPathInType
Sourceimpl PartialEq for QualifiedPathInType
impl PartialEq for QualifiedPathInType
Sourceimpl Print for QualifiedPathInType
impl Print for QualifiedPathInType
Sourcefn print_non_ws(&self, f: &mut PrintFmt)
fn print_non_ws(&self, f: &mut PrintFmt)
Prints this type onto a writer excluding whitespace Read more
Sourceimpl Serialize for QualifiedPathInType
impl Serialize for QualifiedPathInType
impl Eq for QualifiedPathInType
impl StructuralPartialEq for QualifiedPathInType